Add a line search based minimizer.
1. Add a line search based minimization loop.
2. Currently this loop supports steepest descent and three
kinds of non-linear conjugate gradient algorithms.
3. Update SolverImpl to talk to LineSearchMinimizer.
4. Update IterationCallback to carry information about
line search.
5. Update LineSearch to take the initial point as input,
saving on one function evaluation.
6. Updates to the external API.
Change-Id: I901a0e89fc948451ab34c743e70f3dec57c9405e
diff --git a/internal/ceres/line_search.h b/internal/ceres/line_search.h
index bc43329..fccf63b 100644
--- a/internal/ceres/line_search.h
+++ b/internal/ceres/line_search.h
@@ -136,7 +136,7 @@
//
// g is the gradient f'(x) at x.
//
- // Both f and g must not be NULL;
+ // f must not be null. The gradient is computed only if g is not null.
virtual bool Evaluate(double x, double* f, double* g) = 0;
};
@@ -156,12 +156,18 @@
// Perform the line search.
//
// initial_step_size must be a positive number. summary must not be
// null and will contain the result of the line search.
//
// Summary::success is true if a non-zero step size is found.
virtual void Search(const LineSearch::Options& options,
double initial_step_size,
+ double initial_cost,
+ double initial_gradient,
Summary* summary) = 0;
};
@@ -195,6 +201,8 @@
virtual ~ArmijoLineSearch() {}
virtual void Search(const LineSearch::Options& options,
double initial_step_size,
+ double initial_cost,
+ double initial_gradient,
Summary* summary);
};
@@ -156,12 +156,18 @@
// Perform the line search.
//
- // initial_step_size must be a positive number. summary must not be
- // null and will contain the result of the line search.
+ // initial_step_size must be a positive number.
+ //
+ // initial_cost and initial_gradient are the values and gradient of
+ // the function at zero.
+ // summary must not be null and will contain the result of the line
+ // search.
//
// Summary::success is true if a non-zero step size is found.